"use client";

import Image from "next/image";
import { useState } from "react";
import eye_off from "./icons/eye-off.svg";
import eye_on from "./icons/eye-on.svg";

interface IChangePasswordInputProps
  extends React.InputHTMLAttributes<HTMLInputElement> {
  label: string;
  error: string;
}

const ChangePasswordInput: React.FC<IChangePasswordInputProps> = ({
  label,
  error,
  placeholder,
  name,
  onChange,
  value,
}: IChangePasswordInputProps) => {
  const [isOpen, setIsOpen] = useState<boolean>(false);
  return (
    <div className="flex flex-col gap-2">
      <label className="font-bold leading-5 text-gray-700">{label}</label>
      <div
        className={`py-[10px] px-[14px] flex items-center justify-between border border-gray-300 rounded-md shadow-sm bg-gray-200${
          error ? "-with-error" : ""
        }`}
      >
        <input
          onChange={onChange}
          value={value}
          name={name}
          placeholder={placeholder}
          type={isOpen ? "text" : "password"}
          className="w-full text-[14px] placeholder:leading-6 bg-gray-200"
        />
        <button onClick={() => setIsOpen((prev) => !prev)} type="button">
          <Image src={isOpen ? eye_on : eye_off} alt="Eye Icon" />
        </button>
      </div>
      {error ? (
        <p className="text-[14px] leading-5 text-red-500">{error}</p>
      ) : null}
    </div>
  );
};

export default ChangePasswordInput;
